structure(list(method = "PUT", url = "/stream?logical-path=%2FtempZone%2Fhome%2Frods%2Ftestthat%2Fdfr.csv&offset=0&count=2000&truncate=true", 
    status_code = 200L, headers = structure(list(Server = "nginx/1.23.1", 
        Date = "Sun, 29 Oct 2023 09:45:33 GMT", `Content-Length` = "33", 
        Connection = "keep-alive", `Access-Control-Allow-Origin` = "*", 
        `Access-Control-Allow-Headers` = "*", `Access-Control-Allow-Methods` = "AUTHORIZATION,ACCEPT,GET,POST,OPTIONS,PUT,DELETE"), class = "httr2_headers"), 
    body = as.raw(c(0x7b, 0x22, 0x63, 0x6f, 0x64, 0x65, 0x22, 
    0x3a, 0x20, 0x30, 0x2c, 0x20, 0x22, 0x6d, 0x65, 0x73, 0x73, 
    0x61, 0x67, 0x65, 0x22, 0x3a, 0x20, 0x22, 0x53, 0x75, 0x63, 
    0x63, 0x65, 0x73, 0x73, 0x22, 0x7d))), class = "httr2_response")
